# coding: utf-8
import django
try:
    from django.conf.urls import url
except ImportError:
    from django.conf.urls.defaults import url
from . import views


urlpatterns = [
    url(r"^routes\.js$", views.routes, name="jsroutes"),
]

if django.VERSION < (1, 8):
    try:
        from django.conf.urls import patterns
    except ImportError:
        from django.conf.urls.defaults import patterns
    urlpatterns = patterns('', *urlpatterns)



from django.test import TestCase
from .utils import javascript


class BaseCollectUrlsTest(TestCase):
    def test_collect_url(self):
        self.assertIn('["jsroutes", "^/routes\\\\.js$"]', javascript)
        self.assertIn('["admin:index", "^/admin/$"]', javascript)
        self.assertIn('admin:sites_site_change', javascript)
